@@ -23,21 +23,21 @@
 interface <- list(
     get_file_id=function() {
         "This function implements the HDF5-API function H5Iget_file_id."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5I.html#Identify-GetFileId} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5I_GET_FILE_ID} for details."
 
         fid <- .Call("R_H5Iget_file_id", self$id, PACKAGE="hdf5r")$return_val
         return(H5File$new(id=fid))
     },
     get_obj_type=function() {
         "This function implements the HDF5-API function H5Iget_type."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5I.html#Identify-GetType} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5I_GET_TYPE} for details."
 
         res <- .Call("R_H5Iget_type", self$id, PACKAGE="hdf5r")$return_val
         return(res)
     },
     get_ref=function() {
         "This function implements the HDF5-API function H5Iget_ref."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5I.html#Identify-GetRef} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5I_GET_REF} for details."
 
         res <- .Call("R_H5Iget_ref", self$id, PACKAGE="hdf5r")$return_val
         if(res < 0) {
@@ -47,7 +47,7 @@ interface <- list(
     },
     inc_ref=function() {
         "This function implements the HDF5-API function H5Iinc_ref."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5I.html#Identify-IncRef} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5I_INC_REF} for details."
 
         res <- .Call("R_H5Iinc_ref", self$id, PACKAGE="hdf5r")$return_val
         if(res < 0) {
@@ -57,7 +57,7 @@ interface <- list(
     },
     dec_ref=function() {
         "This function implements the HDF5-API function H5Idec_ref."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5I.html#Identify-DecRef} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5I_DEC_REF} for details."
 
         res <- .Call("R_H5Idec_ref", self$id, PACKAGE="hdf5r")$return_val
         if(res < 0) {
@@ -70,9 +70,9 @@ interface <- list(
 commonFG <- list(
     open=function(name, link_access_pl=h5const$H5P_DEFAULT, dataset_access_pl=h5const$H5P_DEFAULT, type_access_pl=h5const$H5P_DEFAULT) {
         "Opens groups, datasets or types using the appropriate HDF5-API functions. Please see the documentation at"
-        "\\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5D.html#Dataset-Open} for datasets, "
-        "\\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5O.html#Object-Open} for types and "
-        "\\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5O.html#Object-Open} for general objects."
+        "\\url{https://portal.hdfgroup.org/display/HDF5/H5D_OPEN} for datasets, "
+        "\\url{https://portal.hdfgroup.org/display/HDF5/H5O_OPEN} for types and "
+        "\\url{https://portal.hdfgroup.org/display/HDF5/H5O_OPEN} for general objects."
 
         if (length(name)!=1 || !is.character(name)) stop("'name' must be a character string of length 1")
 
@@ -104,7 +104,7 @@ commonFG <- list(
     },
     open_by_idx=function(n, group_name=".", index_type=h5const$H5_INDEX_NAME, order=h5const$H5_ITER_NATIVE, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Oopen_by_idx."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5O.html#Object-OpenByIdx} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5O_OPEN_BY_IDX} for details."
 
         if (length(group_name)!=1 || !is.character(group_name)) stop("'group_name' must be a character string of length 1")
 
@@ -142,7 +142,7 @@ commonFG <- list(
     },
     exists=function(name, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lexists."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-Exists} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_EXISTS} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
         res <- .Call("R_H5Lexists", self$id, name, link_access_pl$id, PACKAGE = "hdf5r")$return_val
@@ -163,7 +163,7 @@ commonFG <- list(
     },
     link=function(obj, new_link_name, link_create_pl=h5const$H5P_DEFAULT, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Olink."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5O.html#Object-Link} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5O_LINK} for details."
 
         if(!(inherits(obj, "H5D") || inherits(obj, "H5Group") || inherits(obj, "H5T"))) {
             stop("obj has to be a group, dataset or type")
@@ -179,7 +179,7 @@ commonFG <- list(
     },
     obj_copy_to=function(dst_loc, dst_name, src_name, object_copy_pl=h5const$H5P_DEFAULT, link_create_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Ocopy."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5O.html#Object-Copy} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5O_COPY} for details."
 
         if(!(inherits(dst_loc, "H5File") || inherits(dst_loc, "H5Group"))) {
             stop("dst_loc has to be a file or group")
@@ -195,7 +195,7 @@ commonFG <- list(
     },
     obj_copy_from=function(src_loc, src_name, dst_name, object_copy_pl=h5const$H5P_DEFAULT, link_create_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Ocopy."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5O.html#Object-Copy} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5O_COPY} for details."
 
         if(!(inherits(src_loc, "H5File") || inherits(src_loc, "H5Group"))) {
             stop("src_loc has to be a file or group")
@@ -211,7 +211,7 @@ commonFG <- list(
     },
     obj_info_by_idx=function(n, group_name=".", index_field=h5const$H5_INDEX_NAME, order=h5const$H5_ITER_NATIVE, remove_internal_use_only=TRUE) {
         "This function implements the HDF5-API function H5Oget_info_by_idx."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5O.html#Object-GetInfoByIdx} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5O_GET_INFO_BY_IDX} for details."
         if(group_name!="." && !self$exists(group_name)) {
             stop(paste(group_name, " does not exist"))
         }
@@ -232,7 +232,7 @@ commonFG <- list(
     },
     obj_info_by_name=function(object_name, remove_internal_use_only=TRUE) {
         "This function implements the HDF5-API function H5Oget_info_by_name."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5O.html#Object-GetInfoByName} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5O_GET_INFO_BY_NAME} for details."
 
         if(!self$exists(object_name)) {
             stop(paste(object_name, " does not exist"))
@@ -253,7 +253,7 @@ commonFG <- list(
     },
     group_info=function() {
         "This function implements the HDF5-API function H5Gget_info."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5G.html#Group-GetInfo} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5G_GET_INFO} for details."
 
         res <- .Call("R_H5Gget_info", self$id, request_empty(1), PACKAGE = "hdf5r")
         if(res$return_val < 0) {
@@ -263,7 +263,7 @@ commonFG <- list(
     },
     group_info_by_name=function(name, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Gget_info_by_name."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5G.html#Group-GetInfoByName} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5G_GET_INFO_BY_NAME} for details."
 
         res <- .Call("R_H5Gget_info_by_name", self$id, name, request_empty(1), link_access_pl$id,
                      PACKAGE = "hdf5r")
@@ -275,7 +275,7 @@ commonFG <- list(
     group_info_by_idx=function(n, group_name=".",  index_field=h5const$H5_INDEX_NAME, order=h5const$H5_ITER_NATIVE,
         link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Gget_info_by_idx."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5G.html#Group-GetInfoByIdx} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5G_GET_INFO_BY_IDX} for details."
 
         if(group_name!="." && !self$exists(group_name)) {
             stop(paste(group_name, " does not exist"))
@@ -290,8 +290,8 @@ commonFG <- list(
     create_group=function(name, link_create_pl=h5const$H5P_DEFAULT, group_create_pl=h5const$H5P_DEFAULT,
         group_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Gcreate2 and H5Gcreate_anon (if name is NULL). Please see the documentation at"
-        "\\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5G.html#Group-Create2} for regular groups and"
-        "\\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5G.html#Group-CreateAnon} for anonymous groups for details."
+        "\\url{https://portal.hdfgroup.org/display/HDF5/H5G_CREATE2} for regular groups and"
+        "\\url{https://portal.hdfgroup.org/display/HDF5/H5G_CREATE_ANON} for anonymous groups for details."
 
         if(!(is.null(name) || is.character(name))) {
             stop("name has to be NULL or a character vector")
@@ -320,8 +320,8 @@ commonFG <- list(
         "This function is the main interface to create a new dataset. Its parameters allow for customization of the default"
         "behavior, i.e. in order to get a specific datatype, a certain chunk size or dataset dimensionality."
         "Also note that this function implements the HDF5-API function H5Dcreate2 and H5Dcreate_anon (if name is NULL). Please see the documentation at"
-        "\\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5D.html#Dataset-Create2} for regular groups and"
-        "\\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5D.html#Dataset-CreateAnon} for anonymous groups for details."
+        "\\url{https://portal.hdfgroup.org/display/HDF5/H5D_CREATE2} for regular groups and"
+        "\\url{https://portal.hdfgroup.org/display/HDF5/H5D_CREATE_ANON} for anonymous groups for details."
         "@param name The name of the new dataset. If missing, an anonymous dataset is created"
         "@param robj An R-object to take as a template for creating the dataset. Either \\code{robj} or both \\code{dtype} and {space}"
         "have to be provided"
@@ -455,7 +455,7 @@ commonFG <- list(
     commit=function(name, dtype, link_create_pl=h5const$H5P_DEFAULT, type_create_pl=h5const$H5P_DEFAULT,
         type_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Tcommit2."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5T.html#Datatype-Commit2} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5T_COMMIT2} for details."
 
         if(missing(name)) {
             name <- character(0)
@@ -492,7 +492,7 @@ commonFG <- list(
     ## functions around the link interface
     link_create_hard=function(obj_loc, obj_name, link_name, link_create_pl=h5const$H5P_DEFAULT, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lcreate_hard."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-CreateHard} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_CREATE_HARD} for details."
 
         if(!(inherits(obj_loc, "H5File") || inherits(obj_loc, "H5Group"))) {
             stop("src_loc has to be a file or group")
@@ -509,7 +509,7 @@ commonFG <- list(
     },
     link_create_soft=function(target_path, link_name, link_create_pl=h5const$H5P_DEFAULT, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lcreate_soft."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-CreateSoft} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_CREATE_SOFT} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
         check_pl(link_create_pl, "H5P_LINK_CREATE")
@@ -525,7 +525,7 @@ commonFG <- list(
     link_create_external=function(target_filename, target_obj_name, link_name, link_create_pl=h5const$H5P_DEFAULT,
         link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lcreate_external."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-CreateExternal} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_CREATE_EXTERNAL} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
         check_pl(link_create_pl, "H5P_LINK_CREATE")
@@ -540,7 +540,7 @@ commonFG <- list(
     },
     link_exists=function(name, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lexists."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-Exists} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_EXISTS} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
 
@@ -552,7 +552,7 @@ commonFG <- list(
     },
     link_move_from=function(src_loc, src_name, dst_name, link_create_pl=h5const$H5P_DEFAULT, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lmove."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-Move} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_MOVE} for details."
 
         if(!(inherits(src_loc, "H5File") || inherits(src_loc, "H5Group"))) {
             stop("src_loc has to be a file or group")
@@ -569,7 +569,7 @@ commonFG <- list(
     },
     link_move_to=function(dst_loc, dst_name, src_name, link_create_pl=h5const$H5P_DEFAULT, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lmove."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-Move} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_MOVE} for details."
 
         if(!(inherits(dst_loc, "H5File") || inherits(dst_loc, "H5Group"))) {
             stop("src_loc has to be a file or group")
@@ -586,7 +586,7 @@ commonFG <- list(
     },
     link_copy_from=function(src_loc, src_name, dst_name, link_create_pl=h5const$H5P_DEFAULT, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lcopy."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-Copy} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_COPY} for details."
 
         if(!(inherits(src_loc, "H5File") || inherits(src_loc, "H5Group"))) {
             stop("src_loc has to be a file or group")
@@ -603,7 +603,7 @@ commonFG <- list(
     },
     link_copy_to=function(dst_loc, dst_name, src_name, link_create_pl=h5const$H5P_DEFAULT, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lcopy."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-Copy} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_COPY} for details."
 
         if(!(inherits(dst_loc, "H5File") || inherits(dst_loc, "H5Group"))) {
             stop("src_loc has to be a file or group")
@@ -620,7 +620,7 @@ commonFG <- list(
     },
     link_delete=function(name, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Ldelete."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-Delete} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_DELETE} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
 
@@ -634,7 +634,7 @@ commonFG <- list(
     link_delete_by_idx=function(n, group_name=".", index_field=h5const$H5_INDEX_NAME, order=h5const$H5_ITER_NATIVE,
         link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Ldelete_by_idx."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-DeleteByIdx} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_DELETE_BY_IDX} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
 
@@ -651,7 +651,7 @@ commonFG <- list(
     },
     link_info=function(name, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lget_info."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-GetInfo} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_GET_INFO} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
 
@@ -664,7 +664,7 @@ commonFG <- list(
     link_info_by_idx=function(n, group_name=".", index_field=h5const$H5_INDEX_NAME, order=h5const$H5_ITER_NATIVE,
         link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lget_info_by_idx."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-GetInfoByIdx} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_GET_INFO_BY_IDX} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
 
@@ -681,7 +681,7 @@ commonFG <- list(
     },
     link_value=function(name, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lget_val."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-GetVal} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_GET_VAL} for details."
 
         ## first check if it is a soft or external link, otherwise return NA
         linfo <- self$link_info(name=name, link_access_pl=link_access_pl)
@@ -715,7 +715,7 @@ commonFG <- list(
     link_value_by_idx=function(n, group_name=".", index_field=h5const$H5_INDEX_NAME, order=h5const$H5_ITER_NATIVE,
         link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lget_val_by_idx."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-GetValByIdx} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_GET_VAL_BY_IDX} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
 
@@ -755,7 +755,7 @@ commonFG <- list(
     },
     link_name_by_idx=function(n, group_name, idx_type=h5const$H5_INDEX_NAME, order=h5const$H5_ITER_NATIVE, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Lget_name_by_idx."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5L.html#Link-GetNameByIdx} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5L_GET_NAME_BY_IDX} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
 
@@ -776,7 +776,7 @@ commonFG <- list(
     },
     mount=function(name, child) {
         "This function implements the HDF5-API function H5Fmount."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5F.html#File-Mount} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5F_MOUNT} for details."
         if(!is.character(name) || length(name) != 1) {
             stop("name has to be a character vector of length 1")
         }
@@ -794,7 +794,7 @@ commonFG <- list(
     },
     unmount=function(name) {
         "This function implements the HDF5-API function H5Funmount."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5F.html#File-Unmount} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5F_UNMOUNT} for details."
         if(!is.character(name) || length(name) != 1) {
             stop("name has to be a character vector of length 1")
         }
@@ -816,7 +816,7 @@ commonFG <- list(
 commonFG_active <- list(
         names=function(link_access_pl=h5const$H5P_DEFAULT) {
         "Returns the names of the items in the group or at the root of the file"
-        "@param link_access_pl The link-access property list. See \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5P.html} for more detail."
+        "@param link_access_pl The link-access property list. See \\url{https://portal.hdfgroup.org/display/HDF5/Link+Access+Properties} for more detail."
         ginfo <- self$group_info()
         nlinks <- ginfo$nlinks
         res <- character(nlinks)
@@ -837,7 +837,7 @@ commonFG_active <- list(
 commonFGDT <- list(
     obj_info=function(remove_internal_use_only=TRUE) {
         "This function implements the HDF5-API function H5Oget_info."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5O.html#Object-GetInfo} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5O_GET_INFO} for details."
 
         res <- .Call("R_H5Oget_info", self$id, request_empty(1), PACKAGE = "hdf5r")
         if(res$return_val < 0) {
@@ -854,7 +854,7 @@ commonFGDT <- list(
     },
     get_obj_name=function() {
         "This function implements the HDF5-API function H5Iget_name."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5I.html#Identify-GetName} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5I_GET_NAME} for details."
 
         ## get size of the name
         name_size <- .Call("R_H5Iget_name", self$id, character(0), 0, PACKAGE="hdf5r")$return_val
@@ -875,7 +875,7 @@ commonFGDT <- list(
     ## functions that work on attributes
     create_attr=function(attr_name, robj=NULL, dtype=NULL, space=NULL) {
         "This function implements the HDF5-API function H5Acreate2."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-Create2} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_CREATE2} for details."
 
         if(!is.character(attr_name) || length(attr_name) != 1) {
             stop("'attr_name' has to be a character vector of length 1")
@@ -912,7 +912,7 @@ commonFGDT <- list(
     },
     attr_open=function(attr_name) {
         "This function implements the HDF5-API function H5Aopen."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-Open} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_OPEN} for details."
 
         if(!is.character(attr_name) || length(attr_name) != 1) {
             stop("'attr_name' has to be a character vector of length 1")
@@ -927,7 +927,7 @@ commonFGDT <- list(
     },
     create_attr_by_name=function(attr_name, obj_name, robj=NULL, dtype=NULL, space=NULL, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Acreate_by_name."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-CreateByName} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_CREATE_BY_NAME} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
 
@@ -965,7 +965,7 @@ commonFGDT <- list(
     },
     attr_open_by_name=function(attr_name, obj_name, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Aopen_by_name."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-OpenByName} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_OPEN_BY_NAME} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
 
@@ -985,7 +985,7 @@ commonFGDT <- list(
     },
     attr_open_by_idx=function(n, obj_name, idx_type=h5const$H5_INDEX_NAME, order=h5const$H5_ITER_NATIVE, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Aopen_by_idx."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-OpenByIdx} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_OPEN_BY_IDX} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
 
@@ -1003,7 +1003,7 @@ commonFGDT <- list(
     },
     attr_exists_by_name=function(attr_name, obj_name, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Aexists_by_name."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-ExistsByName} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_EXISTS_BY_NAME} for details."
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
 
         if(!is.character(obj_name) || length(obj_name) != 1) {
@@ -1020,7 +1020,7 @@ commonFGDT <- list(
     },
     attr_exists=function(attr_name) {
         "This function implements the HDF5-API function H5Aexists."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-Exists} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_EXISTS} for details."
 
         if(!is.character(attr_name) || length(attr_name) != 1) {
             stop("'attr_name' has to be a character vector of length 1")
@@ -1033,7 +1033,7 @@ commonFGDT <- list(
     },
    attr_rename_by_name=function(old_attr_name, new_attr_name, obj_name, link_access_pl=h5const$H5P_DEFAULT) {
        "This function implements the HDF5-API function H5Arename_by_name."
-       "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-RenameByName} for details."
+       "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_RENAME_BY_NAME} for details."
 
        check_pl(link_access_pl, "H5P_LINK_ACCESS")
 
@@ -1054,7 +1054,7 @@ commonFGDT <- list(
     },
     attr_rename=function(old_attr_name, new_attr_name) {
         "This function implements the HDF5-API function H5Arename."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-Rename} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_RENAME} for details."
 
         if(!is.character(old_attr_name) || length(old_attr_name) != 1) {
             stop("'old_attr_name' has to be a character vector of length 1")
@@ -1070,7 +1070,7 @@ commonFGDT <- list(
     },
     attr_delete=function(attr_name) {
         "This function implements the HDF5-API function H5Adelete."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-Delete} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_DELETE} for details."
 
         if(!is.character(attr_name) || length(attr_name) != 1) {
             stop("'attr_name' has to be a character vector of length 1")
@@ -1083,7 +1083,7 @@ commonFGDT <- list(
     },
     attr_delete_by_name=function(attr_name, obj_name, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Adelete_by_name."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-DeleteByName} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_DELETE_BY_NAME} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
         if(!is.character(obj_name) || length(obj_name) != 1) {
@@ -1101,7 +1101,7 @@ commonFGDT <- list(
     },
     attr_delete_by_idx=function(n, obj_name, idx_type=h5const$H5_INDEX_NAME, order=h5const$H5_ITER_NATIVE, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Adelete_by_idx."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-DeleteByIdx} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_DELETE_BY_IDX} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
         if(!is.character(obj_name) || length(obj_name) != 1) {
@@ -1117,7 +1117,7 @@ commonFGDT <- list(
     },
     attr_info_by_name=function(attr_name, obj_name, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Aget_info_by_name."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-GetInfoByName} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_GET_INFO_BY_NAME} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
         if(!is.character(obj_name) || length(obj_name) != 1) {
@@ -1135,7 +1135,7 @@ commonFGDT <- list(
     },
     attr_info_by_idx=function(n, obj_name, idx_type=h5const$H5_INDEX_NAME, order=h5const$H5_ITER_NATIVE, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Aget_info_by_idx."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-GetInfoByIdx} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_GET_INFO_BY_IDX} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
         if(!is.character(obj_name) || length(obj_name) != 1) {
@@ -1150,7 +1150,7 @@ commonFGDT <- list(
     },
     attr_name_by_idx=function(n, obj_name, idx_type=h5const$H5_INDEX_NAME, order=h5const$H5_ITER_NATIVE, link_access_pl=h5const$H5P_DEFAULT) {
         "This function implements the HDF5-API function H5Aget_name_by_idx."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5A.html#Annot-GetNameByIdx} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5A_GET_NAME_BY_IDX} for details."
 
         check_pl(link_access_pl, "H5P_LINK_ACCESS")
         if(!is.character(obj_name) || length(obj_name) != 1) {
@@ -1182,7 +1182,7 @@ commonFGT <- list(
     create_reference=function(name=".", space=NULL) {
         "This function implements the HDF5-API function H5Rcreate. If \\code{space=NULL} then a \\code{H5R_OBJECT} reference"
         "is created, otherwise a \\code{H5R_DATASET_REGION} reference"
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5R.html#Reference-Create} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5R_CREATE} for details."
 
         if(is.null(space)) {
             ref_type <- h5const$H5R_OBJECT
@@ -1207,7 +1207,7 @@ commonFGT <- list(
 commonFGDTA <- list(
     flush=function(scope=h5const$H5F_SCOPE_GLOBAL) {
         "This function implements the HDF5-API function H5Fflush."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5F.html#File-Flush} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5F_FLUSH} for details."
 
         if(self$is_valid) {
             res <- .Call("R_H5Fflush", self$id, scope, PACKAGE="hdf5r")$return_val
@@ -1222,7 +1222,7 @@ commonFGDTA <- list(
     },
     get_filename=function() {
         "This function implements the HDF5-API function H5Fget_name."
-        "Please see the documentation at \\url{https://www.hdfgroup.org/HDF5/doc/RM/RM_H5F.html#File-GetName} for details."
+        "Please see the documentation at \\url{https://portal.hdfgroup.org/display/HDF5/H5F_GET_NAME} for details."
 
         ## get size of the name
         name_size <- .Call("R_H5Fget_name", self$id, character(0), 0, PACKAGE="hdf5r")$return_val
