@@ -54,6 +54,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5D[] = {
 {"R_H5Dformat_convert", (DL_FUNC) &R_H5Dformat_convert, 1},
 {"R_H5Dget_access_plist", (DL_FUNC) &R_H5Dget_access_plist, 1},
 {"R_H5Dget_chunk_index_type", (DL_FUNC) &R_H5Dget_chunk_index_type, 2},
+{"R_H5Dget_chunk_storage_size", (DL_FUNC) &R_H5Dget_chunk_storage_size, 3},
 {"R_H5Dget_create_plist", (DL_FUNC) &R_H5Dget_create_plist, 1},
 {"R_H5Dget_offset", (DL_FUNC) &R_H5Dget_offset, 1},
 {"R_H5Dget_space", (DL_FUNC) &R_H5Dget_space, 1},
@@ -112,6 +113,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5F[] = {
 {"R_H5Fformat_convert", (DL_FUNC) &R_H5Fformat_convert, 1},
 {"R_H5Fget_access_plist", (DL_FUNC) &R_H5Fget_access_plist, 1},
 {"R_H5Fget_create_plist", (DL_FUNC) &R_H5Fget_create_plist, 1},
+{"R_H5Fget_eoa", (DL_FUNC) &R_H5Fget_eoa, 2},
 {"R_H5Fget_file_image", (DL_FUNC) &R_H5Fget_file_image, 4},
 {"R_H5Fget_filesize", (DL_FUNC) &R_H5Fget_filesize, 2},
 {"R_H5Fget_free_sections", (DL_FUNC) &R_H5Fget_free_sections, 4},
@@ -121,17 +123,23 @@ R_CallMethodDef library_WRAPPER_AUTO_H5F[] = {
 {"R_H5Fget_intent", (DL_FUNC) &R_H5Fget_intent, 2},
 {"R_H5Fget_mdc_config", (DL_FUNC) &R_H5Fget_mdc_config, 2},
 {"R_H5Fget_mdc_hit_rate", (DL_FUNC) &R_H5Fget_mdc_hit_rate, 2},
+{"R_H5Fget_mdc_image_info", (DL_FUNC) &R_H5Fget_mdc_image_info, 3},
 {"R_H5Fget_mdc_logging_status", (DL_FUNC) &R_H5Fget_mdc_logging_status, 3},
 {"R_H5Fget_mdc_size", (DL_FUNC) &R_H5Fget_mdc_size, 5},
 {"R_H5Fget_metadata_read_retry_info", (DL_FUNC) &R_H5Fget_metadata_read_retry_info, 2},
 {"R_H5Fget_name", (DL_FUNC) &R_H5Fget_name, 3},
 {"R_H5Fget_obj_count", (DL_FUNC) &R_H5Fget_obj_count, 2},
 {"R_H5Fget_obj_ids", (DL_FUNC) &R_H5Fget_obj_ids, 4},
+{"R_H5Fget_page_buffering_stats", (DL_FUNC) &R_H5Fget_page_buffering_stats, 6},
+{"R_H5Fincrement_filesize", (DL_FUNC) &R_H5Fincrement_filesize, 2},
 {"R_H5Fis_hdf5", (DL_FUNC) &R_H5Fis_hdf5, 1},
 {"R_H5Fmount", (DL_FUNC) &R_H5Fmount, 4},
 {"R_H5Fopen", (DL_FUNC) &R_H5Fopen, 3},
 {"R_H5Freopen", (DL_FUNC) &R_H5Freopen, 1},
 {"R_H5Freset_mdc_hit_rate_stats", (DL_FUNC) &R_H5Freset_mdc_hit_rate_stats, 1},
+{"R_H5Freset_page_buffering_stats", (DL_FUNC) &R_H5Freset_page_buffering_stats, 1},
+{"R_H5Fset_latest_format", (DL_FUNC) &R_H5Fset_latest_format, 2},
+{"R_H5Fset_libver_bounds", (DL_FUNC) &R_H5Fset_libver_bounds, 3},
 {"R_H5Fset_mdc_config", (DL_FUNC) &R_H5Fset_mdc_config, 2},
 {"R_H5Fstart_mdc_logging", (DL_FUNC) &R_H5Fstart_mdc_logging, 1},
 {"R_H5Fstart_swmr_write", (DL_FUNC) &R_H5Fstart_swmr_write, 1},
@@ -362,11 +370,14 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pget_elink_file_cache_size", (DL_FUNC) &R_H5Pget_elink_file_cache_size, 2},
 {"R_H5Pget_elink_prefix", (DL_FUNC) &R_H5Pget_elink_prefix, 3},
 {"R_H5Pget_est_link_info", (DL_FUNC) &R_H5Pget_est_link_info, 3},
+{"R_H5Pget_evict_on_close", (DL_FUNC) &R_H5Pget_evict_on_close, 2},
 {"R_H5Pget_external", (DL_FUNC) &R_H5Pget_external, 6},
 {"R_H5Pget_external_count", (DL_FUNC) &R_H5Pget_external_count, 1},
 {"R_H5Pget_family_offset", (DL_FUNC) &R_H5Pget_family_offset, 2},
 {"R_H5Pget_fclose_degree", (DL_FUNC) &R_H5Pget_fclose_degree, 2},
 {"R_H5Pget_file_space", (DL_FUNC) &R_H5Pget_file_space, 3},
+{"R_H5Pget_file_space_page_size", (DL_FUNC) &R_H5Pget_file_space_page_size, 2},
+{"R_H5Pget_file_space_strategy", (DL_FUNC) &R_H5Pget_file_space_strategy, 4},
 {"R_H5Pget_fill_time", (DL_FUNC) &R_H5Pget_fill_time, 2},
 {"R_H5Pget_fill_value", (DL_FUNC) &R_H5Pget_fill_value, 4},
 {"R_H5Pget_filter_by_id2", (DL_FUNC) &R_H5Pget_filter_by_id2, 8},
@@ -380,6 +391,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pget_link_phase_change", (DL_FUNC) &R_H5Pget_link_phase_change, 3},
 {"R_H5Pget_local_heap_size_hint", (DL_FUNC) &R_H5Pget_local_heap_size_hint, 2},
 {"R_H5Pget_mdc_config ", (DL_FUNC) &R_H5Pget_mdc_config , 2},
+{"R_H5Pget_mdc_image_config", (DL_FUNC) &R_H5Pget_mdc_image_config, 2},
 {"R_H5Pget_mdc_log_options", (DL_FUNC) &R_H5Pget_mdc_log_options, 5},
 {"R_H5Pget_meta_block_size", (DL_FUNC) &R_H5Pget_meta_block_size, 2},
 {"R_H5Pget_metadata_read_attempts", (DL_FUNC) &R_H5Pget_metadata_read_attempts, 2},
@@ -388,6 +400,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pget_nlinks", (DL_FUNC) &R_H5Pget_nlinks, 2},
 {"R_H5Pget_nprops", (DL_FUNC) &R_H5Pget_nprops, 2},
 {"R_H5Pget_obj_track_times", (DL_FUNC) &R_H5Pget_obj_track_times, 2},
+{"R_H5Pget_page_buffer_size", (DL_FUNC) &R_H5Pget_page_buffer_size, 4},
 {"R_H5Pget_preserve", (DL_FUNC) &R_H5Pget_preserve, 1},
 {"R_H5Pget_shared_mesg_index", (DL_FUNC) &R_H5Pget_shared_mesg_index, 4},
 {"R_H5Pget_shared_mesg_nindexes", (DL_FUNC) &R_H5Pget_shared_mesg_nindexes, 2},
@@ -402,6 +415,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pget_virtual_count", (DL_FUNC) &R_H5Pget_virtual_count, 2},
 {"R_H5Pget_virtual_dsetname", (DL_FUNC) &R_H5Pget_virtual_dsetname, 4},
 {"R_H5Pget_virtual_filename", (DL_FUNC) &R_H5Pget_virtual_filename, 4},
+{"R_H5Pget_virtual_prefix", (DL_FUNC) &R_H5Pget_virtual_prefix, 3},
 {"R_H5Pget_virtual_printf_gap", (DL_FUNC) &R_H5Pget_virtual_printf_gap, 2},
 {"R_H5Pget_virtual_srcspace", (DL_FUNC) &R_H5Pget_virtual_srcspace, 2},
 {"R_H5Pget_virtual_view", (DL_FUNC) &R_H5Pget_virtual_view, 2},
@@ -410,7 +424,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pmodify_filter", (DL_FUNC) &R_H5Pmodify_filter, 5},
 {"R_H5Premove", (DL_FUNC) &R_H5Premove, 2},
 {"R_H5Premove_filter", (DL_FUNC) &R_H5Premove_filter, 2},
-{"R_H5Pset", (DL_FUNC) &R_H5Pset, 4},
+{"R_H5Pset", (DL_FUNC) &R_H5Pset, 3},
 {"R_H5Pset_alignment", (DL_FUNC) &R_H5Pset_alignment, 3},
 {"R_H5Pset_alloc_time", (DL_FUNC) &R_H5Pset_alloc_time, 2},
 {"R_H5Pset_attr_creation_order", (DL_FUNC) &R_H5Pset_attr_creation_order, 2},
@@ -435,11 +449,14 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pset_elink_file_cache_size", (DL_FUNC) &R_H5Pset_elink_file_cache_size, 2},
 {"R_H5Pset_elink_prefix", (DL_FUNC) &R_H5Pset_elink_prefix, 2},
 {"R_H5Pset_est_link_info", (DL_FUNC) &R_H5Pset_est_link_info, 3},
+{"R_H5Pset_evict_on_close", (DL_FUNC) &R_H5Pset_evict_on_close, 2},
 {"R_H5Pset_external", (DL_FUNC) &R_H5Pset_external, 4},
 {"R_H5Pset_family_offset", (DL_FUNC) &R_H5Pset_family_offset, 2},
 {"R_H5Pset_fclose_degree", (DL_FUNC) &R_H5Pset_fclose_degree, 2},
 {"R_H5Pset_file_image", (DL_FUNC) &R_H5Pset_file_image, 4},
 {"R_H5Pset_file_space", (DL_FUNC) &R_H5Pset_file_space, 3},
+{"R_H5Pset_file_space_page_size", (DL_FUNC) &R_H5Pset_file_space_page_size, 2},
+{"R_H5Pset_file_space_strategy", (DL_FUNC) &R_H5Pset_file_space_strategy, 4},
 {"R_H5Pset_fill_time", (DL_FUNC) &R_H5Pset_fill_time, 2},
 {"R_H5Pset_fill_value", (DL_FUNC) &R_H5Pset_fill_value, 3},
 {"R_H5Pset_filter", (DL_FUNC) &R_H5Pset_filter, 5},
@@ -453,6 +470,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pset_link_phase_change", (DL_FUNC) &R_H5Pset_link_phase_change, 3},
 {"R_H5Pset_local_heap_size_hint", (DL_FUNC) &R_H5Pset_local_heap_size_hint, 2},
 {"R_H5Pset_mdc_config", (DL_FUNC) &R_H5Pset_mdc_config, 2},
+{"R_H5Pset_mdc_image_config", (DL_FUNC) &R_H5Pset_mdc_image_config, 2},
 {"R_H5Pset_mdc_log_options", (DL_FUNC) &R_H5Pset_mdc_log_options, 4},
 {"R_H5Pset_meta_block_size", (DL_FUNC) &R_H5Pset_meta_block_size, 2},
 {"R_H5Pset_metadata_read_attempts", (DL_FUNC) &R_H5Pset_metadata_read_attempts, 2},
@@ -460,6 +478,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pset_nbit", (DL_FUNC) &R_H5Pset_nbit, 1},
 {"R_H5Pset_nlinks", (DL_FUNC) &R_H5Pset_nlinks, 2},
 {"R_H5Pset_obj_track_times", (DL_FUNC) &R_H5Pset_obj_track_times, 2},
+{"R_H5Pset_page_buffer_size", (DL_FUNC) &R_H5Pset_page_buffer_size, 4},
 {"R_H5Pset_preserve", (DL_FUNC) &R_H5Pset_preserve, 2},
 {"R_H5Pset_scaleoffset", (DL_FUNC) &R_H5Pset_scaleoffset, 3},
 {"R_H5Pset_shared_mesg_index", (DL_FUNC) &R_H5Pset_shared_mesg_index, 4},
@@ -473,6 +492,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pset_szip", (DL_FUNC) &R_H5Pset_szip, 3},
 {"R_H5Pset_userblock", (DL_FUNC) &R_H5Pset_userblock, 2},
 {"R_H5Pset_virtual", (DL_FUNC) &R_H5Pset_virtual, 5},
+{"R_H5Pset_virtual_prefix", (DL_FUNC) &R_H5Pset_virtual_prefix, 2},
 {"R_H5Pset_virtual_printf_gap", (DL_FUNC) &R_H5Pset_virtual_printf_gap, 2},
 {"R_H5Pset_virtual_view", (DL_FUNC) &R_H5Pset_virtual_view, 2},
 {"R_H5Punregister", (DL_FUNC) &R_H5Punregister, 2},
